@@ -46,21 +46,22 @@ class BaseBackendConfig(BaseModel):
     _backend_class: Type["BaseSessionBackend"] = PrivateAttr()
 
     key: constr(min_length=1, max_length=256) = "session"  # type: ignore[valid-type]
-    """Key to use for the cookie inside the header, e.g. `session=<data>` where 'session' is the cookie key and <data>
-    is the session data.
+    """Key to use for the cookie inside the header, e.g. ``session=<data>`` where ``session`` is the cookie key and
+    ``<data>`` is the session data.
 
     Notes:
         - If a session cookie exceeds 4KB in size it is split. In this case the key will be of the format
-            'session-{segment number}'.
+          ``session-{segment number}``.
+
     """
     max_age: conint(ge=1) = ONE_DAY_IN_SECONDS * 14  # type: ignore[valid-type]
     """Maximal age of the cookie before its invalidated."""
     scopes: Scopes = {ScopeType.HTTP, ScopeType.WEBSOCKET}
-    """Scopes for the middleware - options are 'http' and 'websocket' with the default being both"""
+    """Scopes for the middleware - options are ``http`` and ``websocket`` with the default being both"""
     path: str = "/"
     """Path fragment that must exist in the request url for the cookie to be valid.
 
-    Defaults to '/'.
+    Defaults to ``'/'``.
     """
     domain: Optional[str] = None
     """Domain for which the cookie is valid."""
@@ -71,7 +72,7 @@ class BaseBackendConfig(BaseModel):
     samesite: Literal["lax", "strict", "none"] = "lax"
     """Controls whether or not a cookie is sent with cross-site requests.
 
-    Defaults to 'lax'.
+    Defaults to ``lax``.
     """
     exclude: Optional[Union[str, List[str]]] = None
     """A pattern or list of patterns to skip in the session middleware."""
@@ -83,25 +84,26 @@ class BaseBackendConfig(BaseModel):
         """Use this property to insert the config into a middleware list on one of the application layers.
 
         Examples:
-            ```python
-            from os import urandom
+            .. code-block: python
 
-            from starlite import Starlite, Request, get
-            from starlite.middleware.session import SessionCookieConfig
+                from os import urandom
 
-            session_config = SessionCookieConfig(secret=urandom(16))
+                from starlite import Starlite, Request, get
+                from starlite.middleware.session import SessionCookieConfig
+
+                session_config = SessionCookieConfig(secret=urandom(16))
 
 
-            @get("/")
-            def my_handler(request: Request) -> None:
-                ...
+                @get("/")
+                def my_handler(request: Request) -> None:
+                    ...
 
 
-            app = Starlite(route_handlers=[my_handler], middleware=[session_config.middleware])
-            ```
+                app = Starlite(route_handlers=[my_handler], middleware=[session_config.middleware])
+
 
         Returns:
-            An instance of DefineMiddleware including 'self' as the config kwarg value.
+            An instance of DefineMiddleware including ``self`` as the config kwarg value.
         """
         return DefineMiddleware(SessionMiddleware, backend=self._backend_class(config=self))
 
@@ -114,9 +116,8 @@ class ServerSideSessionConfig(BaseBackendConfig):
 
 
 class BaseSessionBackend(ABC, Generic[ConfigT]):
-    """Abstract session backend defining the interface between a storage mechanism and the application.
-
-    [SessionMiddleware][starlite.middleware.session.SessionMiddleware].
+    """Abstract session backend defining the interface between a storage mechanism and the application
+    :class:`SessionMiddleware`.
 
     This serves as the base class for all client- and server-side backends
     """
@@ -124,10 +125,10 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
     __slots__ = ("config",)
 
     def __init__(self, config: ConfigT) -> None:
-        """Initialize `BaseSessionBackend`
+        """Initialize ``BaseSessionBackend``
 
         Args:
-            config: A instance of a subclass of `BaseBackendConfig`
+            config: A instance of a subclass of ``BaseBackendConfig``
         """
         self.config = config
 
@@ -140,11 +141,11 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
             scope: A scope, if applicable, from which to extract a serializer.
 
         Notes:
-            - The serializer will be extracted from `scope` or fall back
-                to [default_serializer][starlite.utils.default_serializer]
+            - The serializer will be extracted from ``scope`` or fall back
+              to :func:`default_serializer <starlite.utils.default_serializer>`
 
         Returns:
-            `data` serialized as bytes.
+            ``data`` serialized as bytes.
         """
         serializer = get_serializer_from_scope(scope) if scope else None
         return encode_json(data, serializer)
@@ -165,7 +166,7 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
     async def store_in_message(
         self, scope_session: "ScopeSession", message: "Message", connection: ASGIConnection
     ) -> None:
-        """Store the necessary information in the outgoing `Message`
+        """Store the necessary information in the outgoing ``Message``
 
         Args:
             scope_session: Current session to store
@@ -189,44 +190,45 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
 
         Notes:
             - This should not modify the connection's scope. The data returned by this
-            method will be stored in the application scope by the middleware
+              method will be stored in the application scope by the middleware
+
         """
 
 
 class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT]):
     """Base class for server-side backends.
 
-    Implements [BaseSessionBackend][starlite.middleware.session.base.BaseSessionBackend] and defines and
-    interface which subclasses can implement to facilitate the storage of session data
+    Implements :class:`BaseSessionBackend` and defines and interface which subclasses can
+    implement to facilitate the storage of session data.
     """
 
     __slots__ = ()
 
     def __init__(self, config: ServerConfigT) -> None:
-        """Initialize `ServerSideBackend`
+        """Initialize ``ServerSideBackend``
 
         Args:
-            config: A subclass of `ServerSideSessionConfig`
+            config: A subclass of ``ServerSideSessionConfig``
         """
         super().__init__(config=config)
 
     @abstractmethod
     async def get(self, session_id: str) -> Union[bytes, str, Dict[str, Any], None]:
-        """Retrieve data associated with `session_id`.
+        """Retrieve data associated with ``session_id``.
 
         Args:
             session_id: The session-ID
 
         Returns:
-            The session data, if existing, otherwise `None`.
+            The session data, if existing, otherwise ``None``.
         """
 
     @abstractmethod
     async def set(self, session_id: str, data: bytes) -> None:
-        """Store `data` under the `session_id` for later retrieval.
+        """Store ``data`` under the ``session_id`` for later retrieval.
 
-        If there is already data associated with `session_id`, replace
-        it with `data` and reset its expiry time
+        If there is already data associated with ``session_id``, replace
+        it with ``data`` and reset its expiry time
 
         Args:
             session_id: The session-ID
@@ -238,7 +240,7 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
 
     @abstractmethod
     async def delete(self, session_id: str) -> None:
-        """Delete the data associated with `session_id`. Fails silently if no such session-ID exists.
+        """Delete the data associated with ``session_id``. Fails silently if no such session-ID exists.
 
         Args:
             session_id: The session-ID
@@ -256,8 +258,8 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
         """
 
     def generate_session_id(self) -> str:
-        """Generate a new session-ID, with n=[session_id_bytes][starlite.middle
-        ware.session.base.ServerSideSessionConfig.session_id_bytes] random bytes.
+        """Generate a new session-ID, with
+        n=:attr:`session_id_bytes <ServerSideSessionConfig.session_id_bytes>` random bytes.
 
         Returns:
             A session-ID
@@ -267,12 +269,11 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
     async def store_in_message(
         self, scope_session: "ScopeSession", message: "Message", connection: ASGIConnection
     ) -> None:
-        """Store the necessary information in the outgoing `Message` by setting a cookie containing the session-ID.
+        """Store the necessary information in the outgoing ``Message`` by setting a cookie containing the session-ID.
 
         If the session is empty, a null-cookie will be set. Otherwise, the serialised
-        data will be stored using [set][starlite.middleware.session.base.ServerSideBackend.set],
-        under the current session-id. If no session-ID exists, a new ID will be generated using
-        [generate_session_id][starlite.middleware.session.base.ServerSideBackend.generate_session_id].
+        data will be stored using :meth:`set <ServerSideBackend.set>`, under the current session-id. If no session-ID
+        exists, a new ID will be generated using :meth:`generate_session_id <erverSideBackend.generate_session_id>`.
 
         Args:
             scope_session: Current session to store
@@ -311,10 +312,9 @@ class ServerSideBackend(Generic[ServerConfigT], BaseSessionBackend[ServerConfigT
         """Load session data from a connection and return it as a dictionary to be used in the current application
         scope.
 
-        The session-ID will be gathered from a cookie with the key set in the
-        [configuration][starlite.middleware.session.base.BaseBackendConfig.key]. If
-        a cookie is found, its value will be used as the session-ID and data associated
-        with this ID will be loaded using [get][starlite.middleware.session.base.ServerSideBackend.get].
+        The session-ID will be gathered from a cookie with the key set in
+        :attr:`BaseBackendConfig.key`. If a cookie is found, its value will be used as the session-ID and data associated
+        with this ID will be loaded using :meth:`get <ServerSideBackend.get>`.
         If no cookie was found or no data was loaded from the store, this will return an
         empty dictionary.
 
@@ -338,12 +338,11 @@ class SessionMiddleware(AbstractMiddleware, Generic[BaseSessionBackendT]):
     """Starlite session middleware for storing session data."""
 
     def __init__(self, app: "ASGIApp", backend: BaseSessionBackendT) -> None:
-        """Initialize `SessionMiddleware`
+        """Initialize ``SessionMiddleware``
 
         Args:
             app: An ASGI application
-            backend: A [BaseSessionBackend][starlite.middleware.session.base.BaseSessionBackend]
-                instance used to store and retrieve session data
+            backend: A :class:`BaseSessionBackend` instance used to store and retrieve session data
         """
 
         super().__init__(
@@ -365,7 +364,7 @@ class SessionMiddleware(AbstractMiddleware, Generic[BaseSessionBackendT]):
         """
 
         async def wrapped_send(message: "Message") -> None:
-            """Wrap the `send` function.
+            """Wrap the ``send`` function.
 
             Declared in local scope to make use of closure values.
 
